@@ -240,6 +240,7 @@ static int generate_wrapper(StrBuf *buf, const char *target,
 static int generate_boot(StrBuf *buf, const char *module_name,
                          XS_JIT_Func *functions, int num_funcs) {
     char safe_module[256];
+    int i;
     safe_name(module_name, safe_module, sizeof(safe_module));
 
     strbuf_append(buf, "\n/* Boot function */\n");
@@ -272,7 +273,7 @@ static int generate_boot(StrBuf *buf, const char *module_name,
     strbuf_append(buf, "\n");
 
     /* Register each function */
-    for (int i = 0; i < num_funcs; i++) {
+    for (i = 0; i < num_funcs; i++) {
         if (!functions[i].target) break;
 
         char safe_target[256];
@@ -306,6 +307,7 @@ char* xs_jit_generate_code(pTHX_ const char *user_code,
                            XS_JIT_Func *functions,
                            int num_funcs) {
     StrBuf buf;
+    int i;
     strbuf_init(&buf);
 
     /* Standard headers */
@@ -394,7 +396,7 @@ char* xs_jit_generate_code(pTHX_ const char *user_code,
     strbuf_append(&buf, "/* ========== XS Wrappers ========== */\n");
 
     /* Generate wrapper for each function */
-    for (int i = 0; i < num_funcs; i++) {
+    for (i = 0; i < num_funcs; i++) {
         if (!functions[i].target) break;
         generate_wrapper(&buf, functions[i].target, functions[i].source,
                         functions[i].has_varargs, functions[i].is_xs_native);
@@ -615,7 +617,8 @@ int xs_jit_load(pTHX_ const char *module_name, const char *so_file) {
 
 /* Check if any of the target functions are already defined */
 static int functions_already_loaded(pTHX_ XS_JIT_Func *functions, int num_functions) {
-    for (int i = 0; i < num_functions && functions[i].target; i++) {
+    int i;
+    for (i = 0; i < num_functions && functions[i].target; i++) {
         /* Split target into package and function name */
         const char *target = functions[i].target;
         const char *last_colon = strrchr(target, ':');
